@@ -19,14 +19,13 @@ if mode == 'exe':
 if mode == 'test': pass
 
 
-
 '''
 ~/.config/Code/User/keybindings.json
 {
   "key": "ctrl+shift+1",
   "command": "workbench.action.terminal.sendSequence",
   "args": {
-    "text": "python3 /home/quang/.local/lib/python3.10/site-packages/tayto/execute.py ${file} exe\u000D"
+    "text": "python3 /home/quang/Desktop/tayto/src/tayto/execute.py ${file} exe\u000D"
   }
 },
 '''
\ No newline at end of file
